EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Rafts_CreateOrUpdateRaftVariable',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates an item in a database raft.'
GO


IF OBJECT_ID('[Rafts_CreateOrUpdateRaftVariable]') IS NOT NULL DROP PROCEDURE [Rafts_CreateOrUpdateRaftVariable]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Rafts_CreateOrUpdateRaftVariable]
(
	@Raft_Id INT,
	@Variable_Name VARCHAR(50),
	@ValueType_Code CHAR(1),
	@Variable_Value NVARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Variable_Value IS NOT NULL
	BEGIN
		IF EXISTS (SELECT * FROM [RaftVariables] WHERE [Raft_Id] = @Raft_Id AND [Variable_Name] = @Variable_Name)
			UPDATE [RaftVariables]
			   SET [ValueType_Code] = @ValueType_Code,
			       [Variable_Value] = @Variable_Value
			 WHERE [Raft_Id] = @Raft_Id
			   AND [Variable_Name] = @Variable_Name

		ELSE
			INSERT INTO [RaftVariables]
			(
				[Raft_Id],
				[Variable_Name],
				[ValueType_Code],
				[Variable_Value]
			)
			VALUES
			(
				@Raft_Id,
				@ValueType_Code,
				@ValueType_Code,
				@Variable_Value
			)
	END
	ELSE
	BEGIN

		DELETE
		  FROM [RaftVariables]
		 WHERE [Raft_Id] = @Raft_Id
		   AND [Variable_Name] = @Variable_Name

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Rafts_CreateOrUpdateRaftVariable] TO [OtterUser_Role]
